@@ -1,7 +1,7 @@
 /*
  * gtk_anyone.c: Show the user tree as a Gtk+ widget
  * David Maze <dmaze@mit.edu>
- * $Id: gtkanyone.c,v 1.22 2001/11/18 23:17:54 dmaze Exp $
+ * $Id: gtkanyone.c,v 1.24 2001/12/11 04:21:46 dmaze Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -263,6 +263,8 @@ static void rebuild_children(GtkAnyone *anyone)
       }
       
       luser = luser->next;
+      /* We often lose here; why? */
+      g_assert(luser != NULL);
       user = luser->data;
     }
     /* Now we have a guarantee that user == target. */
@@ -335,7 +337,7 @@ static void set_tooltip(GtkAnyone *anyone, GtkWidget *child, zuser *user)
   int n;
   const ZLocations_t *loc;
   
-  tip = zuser_name(user);
+  tip = zuser_principal(user);
   g_string_append(tip, "\n");
   
   /* Also pull the locations out of the user object. */
